@@ -1,3 +1,4 @@
+from rest_framework.parsers import FormParser
 from rest_framework.permissions import AllowAny, IsAdminUser
 from rest_framework.renderers import JSONRenderer
 from rest_framework.views import APIView
@@ -6,7 +7,8 @@ from drf_toolkit.json_parser import JsonParser
 
 
 class JsonApiView(APIView):
-    parser_classes = (JsonParser, )
+    parser_classes = (JsonParser,
+                      FormParser)
     renderer_classes = (JSONRenderer,)
 
 
